unit uPrefs;

{
This code is part of the TiCodEd Application, designed to develop for the
TI-99/4a Homecomputer in a modern, structured way.

BSD License
Copyright (c) 2023, Stefan Bauch, TiCodEd <at> lizardware <dot> de


Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

}

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls, Buttons,
  ExtCtrls, Spin, EditBtn, SpinEx;

type

  { TFormPrefs }

  TFormPrefs = class(TForm)
    BitBtn1: TBitBtn;
    BitBtnOK: TBitBtn;
    CbDevice: TComboBox;
    CbMemoryExp: TCheckBox;
    cbXBtoClipboard: TCheckBox;
    cbAsmList: TCheckBox;
    DirEditInc: TDirectoryEdit;
    DirEditFIAD: TDirectoryEdit;
    EdAssembler: TFileNameEdit;
    EdIntDel: TLabeledEdit;
    GroupBoxAssembler: TGroupBox;
    GroupBoxIntegration: TGroupBox;
    GroupBoxEnvironment: TGroupBox;
    GroupBoxAppearance: TGroupBox;
    EdIntStr: TLabeledEdit;
    Label1: TLabel;
    LabelExample: TLabel;
    LabelFontsize: TLabel;
    RGIntTarget: TRadioGroup;
    SpinEditTimeout: TSpinEdit;
    SpinEditFontSize: TSpinEditEx;
    stFIAD: TStaticText;
    stTimeout: TStaticText;
    procedure BitBtn1Click(Sender: TObject);
    procedure BitBtnOKClick(Sender: TObject);
    procedure DirEditIncExit(Sender: TObject);
    procedure EdAssemblerExit(Sender: TObject);
    procedure EdIntDelExit(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure RGIntTargetClick(Sender: TObject);
    procedure SpinEditFontSizeChange(Sender: TObject);
  private

  public

  end;

var
  FormPrefs: TFormPrefs;

  FontSize : Integer;

implementation

{$R *.lfm}

{ TFormPrefs }

uses IniFiles,FileUtil;

var OldIncPath : String;

procedure TFormPrefs.SpinEditFontSizeChange(Sender: TObject);
begin
  LabelExample.Font.Size:=SpinEditFontSize.value;
end;

procedure TFormPrefs.BitBtnOKClick(Sender: TObject);
begin
  FontSize := SpinEditFontSize.Value;
  FormPrefs.Hide;
end;

procedure TFormPrefs.DirEditIncExit(Sender: TObject);
var ini : TIniFile;
    s : String;
begin
  s := ChangeFileExt(EdAssembler.Text,'.ini');
  if FileExists(s) then begin
    ini := TIniFile.Create(s);
    s := ini.ReadString('CONFIG','INCLUDE','');
    if trim(UpperCase(OldIncPath))<>trim(UpperCase(DirEditInc.text)) then
      if FileExists(trim(DirEditInc.text)+'/RUNTIME1.TXT') then begin
        StringReplace(s,OldIncPath,'',[rfIgnoreCase]);
        StringReplace(s,';;',';',[rfIgnoreCase]);
        if RightStr(s,1)<>';' then s := s + ';';
        s := s + trim(DirEditInc.text);
        ini.WriteString('CONFIG','INCLUDE',s);
        ShowMessage('Success: Include path updated.');
      end else ShowMessage('Error: Include-File not found: '+trim(DirEditInc.text)+'\RUNTIME1.TXT');
    ini.Destroy;
  end else ShowMessage('Error: Assembler INI-File not found: '+s);
end;

procedure TFormPrefs.EdAssemblerExit(Sender: TObject);
begin
  if (EdAssembler.Text<>'') and not FileExists(EdAssembler.Text) then
    ShowMessage('Warning: '+EdAssembler.Text+' not found!');
end;

procedure TFormPrefs.EdIntDelExit(Sender: TObject);
var i,rc : Integer;
begin
  val(EdIntDel.Text,i,rc);
  if rc<>0 then EdIntDel.Text:= '20';
end;

procedure TFormPrefs.FormShow(Sender: TObject);
var s : String;
begin
  OldIncPath:=DirEditInc.Text;
  {$IFDEF WINDOWS}
  GroupBoxIntegration.Enabled:=true;
  if EdAssembler.Text='' then begin
    s:=ExtractFileDir(Paramstr(0))+'\asm\xa99.exe';
    if FileExists(s) then EdAssembler.Text:=s;
  end;
  {$ELSE}
  GroupBoxIntegration.Enabled:=true;
  GroupBoxIntegration.hint:='Full integration only available in Windows';
  GroupBoxIntegration.ShowHint:=true;
  RGIntTarget.Enabled:=false;
  EdIntStr.Enabled:=false;
  EdIntDel.Enabled:=false;
  CbDevice.Enabled:=false;
  GroupBoxAssembler.Enabled:=false;
  {$ENDIF}
end;

procedure TFormPrefs.RGIntTargetClick(Sender: TObject);
begin
  if RgIntTarget.ItemIndex<2 then EdIntStr.Enabled:=false
                             else EdIntStr.Enabled:=true;
end;

procedure TFormPrefs.BitBtn1Click(Sender: TObject);
begin
  FormPrefs.Hide;
end;

end.

